hotspot/src/share/vm/opto/runtime.hpp
changeset 4637 af4d405aacc1
parent 4030 4c471254865e
child 5547 f4b087cbb361
--- a/hotspot/src/share/vm/opto/runtime.hpp	Tue Jan 12 14:56:46 2010 -0800
+++ b/hotspot/src/share/vm/opto/runtime.hpp	Wed Jan 13 15:26:39 2010 -0800
@@ -133,8 +133,9 @@
   // Allocate storage for a objArray or typeArray
   static void new_array_C(klassOopDesc* array_klass, int len, JavaThread *thread);
 
-  // Post-slow-path-allocation step for implementing ReduceInitialCardMarks:
-  static void maybe_defer_card_mark(JavaThread* thread);
+  // Post-slow-path-allocation, pre-initializing-stores step for
+  // implementing ReduceInitialCardMarks
+  static void new_store_pre_barrier(JavaThread* thread);
 
   // Allocate storage for a multi-dimensional arrays
   // Note: needs to be fixed for arbitrary number of dimensions